pub struct Range {
pub offset: u64,
pub length: Option<u64>,
pub hashes: Vec<Hash>,
}Expand description
Represents a range in a file.
Fields
offset: u64The offset in bytes from the beginning of the file.
length: Option<u64>The length in bytes of the range, or None to be the entire remaining of the file.
hashes: Vec<Hash>List of hashes for this range.
Implementations